<?php


namespace FiloBlu\Referrals\Setup;

use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

class UpgradeSchema implements UpgradeSchemaInterface
{

    /**
     * {@inheritdoc}
     */
    public function upgrade(
        SchemaSetupInterface $setup,
        ModuleContextInterface $context
    ) {
        if (version_compare($context->getVersion(), "1.0.1", "<")) {
            $this->addCouponColumnToInvitation($setup, $context);
        }

        if (version_compare($context->getVersion(), '1.0.2', '<')) {
            $this->addGeneratedByReferralToCoupons($setup, $context);
        }

        if (version_compare($context->getVersion(), "1.0.3", "<")) {
            $this->addSentCouponColumnToInvitation($setup, $context);
        }

    }

    public function addCouponColumnToInvitation(SchemaSetupInterface $setup, ModuleContextInterface $context) {

        $installer = $setup;
        $installer->startSetup();

        $eavTable = $installer->getTable('magento_invitation');

        $columns = [
            'coupon_for_who_got_invited' => [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'nullable' => true,
                'LENGTH' => 100,
                'default' => null,
                'comment' => 'Coupon code for who got invited'
            ],
            'coupon_for_who_sent_the_invite' => [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'nullable' => true,
                'LENGTH' => 100,
                'default' => null,
                'comment' => 'Coupon code for who sent the invite'
            ]
        ];

        $connection = $installer->getConnection();
        foreach ($columns as $name => $definition) {
            $connection->addColumn($eavTable, $name, $definition);
        }

        $installer->endSetup();
    }


    public function addGeneratedByReferralToCoupons(SchemaSetupInterface $setup, ModuleContextInterface $context) {
        $installer = $setup;
        $installer->startSetup();

        $eavTable = $installer->getTable('salesrule_coupon');

        $columns = [
            'generated_by_invitation_referral' => [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                'nullable' => true,
                'default' => null,
                'comment' => '1 = Generated by invitation referral'
            ]
        ];

        $connection = $installer->getConnection();
        foreach ($columns as $name => $definition) {
            $connection->addColumn($eavTable, $name, $definition);
        }

        $installer->endSetup();

    }

    public function addSentCouponColumnToInvitation(SchemaSetupInterface $setup, ModuleContextInterface $context) {

        $installer = $setup;
        $installer->startSetup();

        $eavTable = $installer->getTable('magento_invitation');

        $columns = [
            'who_got_invited_cp_sent' => [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                'nullable' => false,
                'LENGTH' => 1,
                'default' => 0,
                'comment' => 'Boolean to keep track of the email sent'
            ],
            'who_sent_the_invite_cp_sent' => [
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                'nullable' => false,
                'LENGTH' => 1,
                'default' => 0,
                'comment' => 'Boolean to keep track of the email sent'
            ]
        ];

        $connection = $installer->getConnection();
        foreach ($columns as $name => $definition) {
            $connection->addColumn($eavTable, $name, $definition);
        }

        $installer->endSetup();
    }

}
